# coding: utf-8

"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing_extensions import Annotated, Self


class ManagedWorkerCreateRequestRuntimeConfig(BaseModel):
    """
    ManagedWorkerCreateRequestRuntimeConfig
    """  # noqa: E501

    num_replicas: Annotated[int, Field(le=1000, strict=True, ge=0)] = Field(
        alias="numReplicas"
    )
    regions: Optional[List[StrictStr]] = Field(
        default=None, description="The region to deploy the worker to"
    )
    cpu_kind: StrictStr = Field(
        description="The kind of CPU to use for the worker", alias="cpuKind"
    )
    cpus: Annotated[int, Field(le=64, strict=True, ge=1)] = Field(
        description="The number of CPUs to use for the worker"
    )
    memory_mb: Annotated[int, Field(le=65536, strict=True, ge=1024)] = Field(
        description="The amount of memory in MB to use for the worker", alias="memoryMb"
    )
    actions: Optional[List[StrictStr]] = None
    slots: Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]] = None
    __properties: ClassVar[List[str]] = [
        "numReplicas",
        "regions",
        "cpuKind",
        "cpus",
        "memoryMb",
        "actions",
        "slots",
    ]

    @field_validator("regions")
    def regions_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "ams",
                    "arn",
                    "atl",
                    "bog",
                    "bos",
                    "cdg",
                    "den",
                    "dfw",
                    "ewr",
                    "eze",
                    "gdl",
                    "gig",
                    "gru",
                    "hkg",
                    "iad",
                    "jnb",
                    "lax",
                    "lhr",
                    "mad",
                    "mia",
                    "nrt",
                    "ord",
                    "otp",
                    "phx",
                    "qro",
                    "scl",
                    "sea",
                    "sin",
                    "sjc",
                    "syd",
                    "waw",
                    "yul",
                    "yyz",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('ams', 'arn', 'atl', 'bog', 'bos', 'cdg', 'den', 'dfw', 'ewr', 'eze', 'gdl', 'gig', 'gru', 'hkg', 'iad', 'jnb', 'lax', 'lhr', 'mad', 'mia', 'nrt', 'ord', 'otp', 'phx', 'qro', 'scl', 'sea', 'sin', 'sjc', 'syd', 'waw', 'yul', 'yyz')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ManagedWorkerCreateRequestRuntimeConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ManagedWorkerCreateRequestRuntimeConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "numReplicas": obj.get("numReplicas"),
                "regions": obj.get("regions"),
                "cpuKind": obj.get("cpuKind"),
                "cpus": obj.get("cpus"),
                "memoryMb": obj.get("memoryMb"),
                "actions": obj.get("actions"),
                "slots": obj.get("slots"),
            }
        )
        return _obj



# coding: utf-8

"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field
from typing_extensions import Self

from hatchet_sdk.clients.cloud_rest.models.tenant_billing_state_get200_response_coupons_inner import (
    TenantBillingStateGet200ResponseCouponsInner,
)
from hatchet_sdk.clients.cloud_rest.models.tenant_billing_state_get200_response_payment_methods_inner import (
    TenantBillingStateGet200ResponsePaymentMethodsInner,
)
from hatchet_sdk.clients.cloud_rest.models.tenant_billing_state_get200_response_plans_inner import (
    TenantBillingStateGet200ResponsePlansInner,
)
from hatchet_sdk.clients.cloud_rest.models.tenant_billing_state_get200_response_subscription import (
    TenantBillingStateGet200ResponseSubscription,
)


class TenantBillingStateGet200Response(BaseModel):
    """
    TenantBillingStateGet200Response
    """  # noqa: E501

    payment_methods: Optional[
        List[TenantBillingStateGet200ResponsePaymentMethodsInner]
    ] = Field(default=None, alias="paymentMethods")
    subscription: TenantBillingStateGet200ResponseSubscription
    plans: Optional[List[TenantBillingStateGet200ResponsePlansInner]] = Field(
        default=None, description="A list of plans available for the tenant."
    )
    coupons: Optional[List[TenantBillingStateGet200ResponseCouponsInner]] = Field(
        default=None, description="A list of coupons applied to the tenant."
    )
    __properties: ClassVar[List[str]] = [
        "paymentMethods",
        "subscription",
        "plans",
        "coupons",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TenantBillingStateGet200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in payment_methods (list)
        _items = []
        if self.payment_methods:
            for _item in self.payment_methods:
                if _item:
                    _items.append(_item.to_dict())
            _dict["paymentMethods"] = _items
        # override the default output from pydantic by calling `to_dict()` of subscription
        if self.subscription:
            _dict["subscription"] = self.subscription.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in plans (list)
        _items = []
        if self.plans:
            for _item in self.plans:
                if _item:
                    _items.append(_item.to_dict())
            _dict["plans"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in coupons (list)
        _items = []
        if self.coupons:
            for _item in self.coupons:
                if _item:
                    _items.append(_item.to_dict())
            _dict["coupons"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TenantBillingStateGet200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "paymentMethods": (
                    [
                        TenantBillingStateGet200ResponsePaymentMethodsInner.from_dict(
                            _item
                        )
                        for _item in obj["paymentMethods"]
                    ]
                    if obj.get("paymentMethods") is not None
                    else None
                ),
                "subscription": (
                    TenantBillingStateGet200ResponseSubscription.from_dict(
                        obj["subscription"]
                    )
                    if obj.get("subscription") is not None
                    else None
                ),
                "plans": (
                    [
                        TenantBillingStateGet200ResponsePlansInner.from_dict(_item)
                        for _item in obj["plans"]
                    ]
                    if obj.get("plans") is not None
                    else None
                ),
                "coupons": (
                    [
                        TenantBillingStateGet200ResponseCouponsInner.from_dict(_item)
                        for _item in obj["coupons"]
                    ]
                    if obj.get("coupons") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa
"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from hatchet_sdk.clients.cloud_rest.models.billing_portal_link_get200_response import (
    BillingPortalLinkGet200Response,
)
from hatchet_sdk.clients.cloud_rest.models.build_get200_response import (
    BuildGet200Response,
)
from hatchet_sdk.clients.cloud_rest.models.github_app_list_branches200_response_inner import (
    GithubAppListBranches200ResponseInner,
)
from hatchet_sdk.clients.cloud_rest.models.github_app_list_installations200_response import (
    GithubAppListInstallations200Response,
)
from hatchet_sdk.clients.cloud_rest.models.github_app_list_installations200_response_pagination import (
    GithubAppListInstallations200ResponsePagination,
)
from hatchet_sdk.clients.cloud_rest.models.github_app_list_installations200_response_rows_inner import (
    GithubAppListInstallations200ResponseRowsInner,
)
from hatchet_sdk.clients.cloud_rest.models.github_app_list_installations200_response_rows_inner_metadata import (
    GithubAppListInstallations200ResponseRowsInnerMetadata,
)
from hatchet_sdk.clients.cloud_rest.models.github_app_list_repos200_response_inner import (
    GithubAppListRepos200ResponseInner,
)
from hatchet_sdk.clients.cloud_rest.models.infra_as_code_create_request import (
    InfraAsCodeCreateRequest,
)
from hatchet_sdk.clients.cloud_rest.models.log_create_request_inner import (
    LogCreateRequestInner,
)
from hatchet_sdk.clients.cloud_rest.models.log_create_request_inner_event import (
    LogCreateRequestInnerEvent,
)
from hatchet_sdk.clients.cloud_rest.models.log_create_request_inner_fly import (
    LogCreateRequestInnerFly,
)
from hatchet_sdk.clients.cloud_rest.models.log_create_request_inner_fly_app import (
    LogCreateRequestInnerFlyApp,
)
from hatchet_sdk.clients.cloud_rest.models.log_create_request_inner_log import (
    LogCreateRequestInnerLog,
)
from hatchet_sdk.clients.cloud_rest.models.log_list200_response import (
    LogList200Response,
)
from hatchet_sdk.clients.cloud_rest.models.log_list200_response_rows_inner import (
    LogList200ResponseRowsInner,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_create_request import (
    ManagedWorkerCreateRequest,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_create_request_build_config import (
    ManagedWorkerCreateRequestBuildConfig,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_create_request_build_config_steps_inner import (
    ManagedWorkerCreateRequestBuildConfigStepsInner,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_create_request_runtime_config import (
    ManagedWorkerCreateRequestRuntimeConfig,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_events_list200_response import (
    ManagedWorkerEventsList200Response,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_events_list200_response_rows_inner import (
    ManagedWorkerEventsList200ResponseRowsInner,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_instances_list200_response import (
    ManagedWorkerInstancesList200Response,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_instances_list200_response_rows_inner import (
    ManagedWorkerInstancesList200ResponseRowsInner,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_list200_response import (
    ManagedWorkerList200Response,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_list200_response_rows_inner import (
    ManagedWorkerList200ResponseRowsInner,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_list200_response_rows_inner_build_config import (
    ManagedWorkerList200ResponseRowsInnerBuildConfig,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_list200_response_rows_inner_build_config_steps_inner import (
    ManagedWorkerList200ResponseRowsInnerBuildConfigStepsInner,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_list200_response_rows_inner_runtime_configs_inner import (
    ManagedWorkerList200ResponseRowsInnerRuntimeConfigsInner,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_update_request import (
    ManagedWorkerUpdateRequest,
)
from hatchet_sdk.clients.cloud_rest.models.metadata_get200_response import (
    MetadataGet200Response,
)
from hatchet_sdk.clients.cloud_rest.models.metadata_get400_response import (
    MetadataGet400Response,
)
from hatchet_sdk.clients.cloud_rest.models.metadata_get400_response_errors_inner import (
    MetadataGet400ResponseErrorsInner,
)
from hatchet_sdk.clients.cloud_rest.models.metrics_cpu_get200_response_inner import (
    MetricsCpuGet200ResponseInner,
)
from hatchet_sdk.clients.cloud_rest.models.metrics_cpu_get200_response_inner_histograms_inner import (
    MetricsCpuGet200ResponseInnerHistogramsInner,
)
from hatchet_sdk.clients.cloud_rest.models.metrics_cpu_get200_response_inner_histograms_inner_histogram import (
    MetricsCpuGet200ResponseInnerHistogramsInnerHistogram,
)
from hatchet_sdk.clients.cloud_rest.models.metrics_cpu_get200_response_inner_histograms_inner_histogram_buckets_inner import (
    MetricsCpuGet200ResponseInnerHistogramsInnerHistogramBucketsInner,
)
from hatchet_sdk.clients.cloud_rest.models.runtime_config_list_actions200_response import (
    RuntimeConfigListActions200Response,
)
from hatchet_sdk.clients.cloud_rest.models.subscription_upsert200_response import (
    SubscriptionUpsert200Response,
)
from hatchet_sdk.clients.cloud_rest.models.subscription_upsert_request import (
    SubscriptionUpsertRequest,
)
from hatchet_sdk.clients.cloud_rest.models.tenant_billing_state_get200_response import (
    TenantBillingStateGet200Response,
)
from hatchet_sdk.clients.cloud_rest.models.tenant_billing_state_get200_response_coupons_inner import (
    TenantBillingStateGet200ResponseCouponsInner,
)
from hatchet_sdk.clients.cloud_rest.models.tenant_billing_state_get200_response_payment_methods_inner import (
    TenantBillingStateGet200ResponsePaymentMethodsInner,
)
from hatchet_sdk.clients.cloud_rest.models.tenant_billing_state_get200_response_plans_inner import (
    TenantBillingStateGet200ResponsePlansInner,
)
from hatchet_sdk.clients.cloud_rest.models.tenant_billing_state_get200_response_subscription import (
    TenantBillingStateGet200ResponseSubscription,
)
from hatchet_sdk.clients.cloud_rest.models.workflow_run_events_get_metrics200_response import (
    WorkflowRunEventsGetMetrics200Response,
)
from hatchet_sdk.clients.cloud_rest.models.workflow_run_events_get_metrics200_response_results_inner import (
    WorkflowRunEventsGetMetrics200ResponseResultsInner,
)



import hashlib
from typing import Annotated, Optional

from pydantic import BaseModel, Field, StrictStr


class Compute(BaseModel):
    pool: Optional[str] = Field(
        default="default",
        description="The name of the compute pool to use",
    )
    num_replicas: Annotated[int, Field(le=1000, strict=True, ge=0)] = Field(
        default=1, alias="num_replicas"
    )
    # TODO: change to ManagedWorkerRegion
    regions: Optional[list[str]] = Field(
        default=None, description="The regions to deploy the worker to"
    )
    cpu_kind: StrictStr = Field(
        description="The kind of CPU to use for the worker", alias="cpu_kind"
    )
    cpus: Annotated[int, Field(le=64, strict=True, ge=1)] = Field(
        description="The number of CPUs to use for the worker"
    )
    memory_mb: Annotated[int, Field(le=65536, strict=True, ge=1024)] = Field(
        description="The amount of memory in MB to use for the worker",
        alias="memory_mb",
    )

    def __json__(self):
        return self.model_dump_json()

    def hash(self):
        return hashlib.sha256(self.__json__().encode()).hexdigest()



# coding: utf-8

"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set, Union

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictFloat,
    StrictInt,
    StrictStr,
    field_validator,
)
from typing_extensions import Self


class TenantBillingStateGet200ResponseCouponsInner(BaseModel):
    """
    TenantBillingStateGet200ResponseCouponsInner
    """  # noqa: E501

    name: StrictStr = Field(description="The name of the coupon.")
    amount_cents: Optional[StrictInt] = Field(
        default=None, description="The amount off of the coupon."
    )
    amount_cents_remaining: Optional[StrictInt] = Field(
        default=None, description="The amount remaining on the coupon."
    )
    amount_currency: Optional[StrictStr] = Field(
        default=None, description="The currency of the coupon."
    )
    frequency: StrictStr = Field(description="The frequency of the coupon.")
    frequency_duration: Optional[StrictInt] = Field(
        default=None, description="The frequency duration of the coupon."
    )
    frequency_duration_remaining: Optional[StrictInt] = Field(
        default=None, description="The frequency duration remaining of the coupon."
    )
    percent: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=None, description="The percentage off of the coupon."
    )
    __properties: ClassVar[List[str]] = [
        "name",
        "amount_cents",
        "amount_cents_remaining",
        "amount_currency",
        "frequency",
        "frequency_duration",
        "frequency_duration_remaining",
        "percent",
    ]

    @field_validator("frequency")
    def frequency_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(["once", "recurring"]):
            raise ValueError("must be one of enum values ('once', 'recurring')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TenantBillingStateGet200ResponseCouponsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TenantBillingStateGet200ResponseCouponsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "name": obj.get("name"),
                "amount_cents": obj.get("amount_cents"),
                "amount_cents_remaining": obj.get("amount_cents_remaining"),
                "amount_currency": obj.get("amount_currency"),
                "frequency": obj.get("frequency"),
                "frequency_duration": obj.get("frequency_duration"),
                "frequency_duration_remaining": obj.get("frequency_duration_remaining"),
                "percent": obj.get("percent"),
            }
        )
        return _obj



# coding: utf-8

"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing_extensions import Self


class ManagedWorkerEventsList200ResponseRowsInner(BaseModel):
    """
    ManagedWorkerEventsList200ResponseRowsInner
    """  # noqa: E501

    id: StrictInt
    time_first_seen: datetime = Field(alias="timeFirstSeen")
    time_last_seen: datetime = Field(alias="timeLastSeen")
    managed_worker_id: StrictStr = Field(alias="managedWorkerId")
    status: StrictStr
    message: StrictStr
    data: Dict[str, Any]
    __properties: ClassVar[List[str]] = [
        "id",
        "timeFirstSeen",
        "timeLastSeen",
        "managedWorkerId",
        "status",
        "message",
        "data",
    ]

    @field_validator("status")
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(["IN_PROGRESS", "SUCCEEDED", "FAILED", "CANCELLED"]):
            raise ValueError(
                "must be one of enum values ('IN_PROGRESS', 'SUCCEEDED', 'FAILED', 'CANCELLED')"
            )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ManagedWorkerEventsList200ResponseRowsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ManagedWorkerEventsList200ResponseRowsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "timeFirstSeen": obj.get("timeFirstSeen"),
                "timeLastSeen": obj.get("timeLastSeen"),
                "managedWorkerId": obj.get("managedWorkerId"),
                "status": obj.get("status"),
                "message": obj.get("message"),
                "data": obj.get("data"),
            }
        )
        return _obj



# flake8: noqa

# import apis into api package
from hatchet_sdk.clients.cloud_rest.api.billing_api import BillingApi
from hatchet_sdk.clients.cloud_rest.api.build_api import BuildApi
from hatchet_sdk.clients.cloud_rest.api.feature_flags_api import FeatureFlagsApi
from hatchet_sdk.clients.cloud_rest.api.github_api import GithubApi
from hatchet_sdk.clients.cloud_rest.api.log_api import LogApi
from hatchet_sdk.clients.cloud_rest.api.managed_worker_api import ManagedWorkerApi
from hatchet_sdk.clients.cloud_rest.api.metadata_api import MetadataApi
from hatchet_sdk.clients.cloud_rest.api.metrics_api import MetricsApi
from hatchet_sdk.clients.cloud_rest.api.tenant_api import TenantApi
from hatchet_sdk.clients.cloud_rest.api.user_api import UserApi
from hatchet_sdk.clients.cloud_rest.api.workflow_api import WorkflowApi



import os
import sys
from typing import Any, Callable, Dict, List

from hatchet_sdk.client import Client
from hatchet_sdk.clients.cloud_rest.models.infra_as_code_create_request import (
    InfraAsCodeCreateRequest,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_create_request_runtime_config import (
    ManagedWorkerCreateRequestRuntimeConfig,
)
from hatchet_sdk.compute.configs import Compute
from hatchet_sdk.logger import logger

# TODO why is this not generating
# from hatchet_sdk.clients.cloud_rest.models.managed_worker_create_request import ManagedWorkerRegion


class ManagedCompute:
    def __init__(
        self, actions: Dict[str, Callable[..., Any]], client: Client, max_runs: int = 1
    ):
        self.actions = actions
        self.client = client
        self.max_runs = max_runs
        self.configs = self.get_compute_configs(self.actions)
        self.cloud_register_enabled = os.environ.get("HATCHET_CLOUD_REGISTER_ID")

        if len(self.configs) == 0:
            logger.debug(
                "no compute configs found, skipping cloud registration and running all actions locally."
            )
            return

        if self.cloud_register_enabled is None:
            logger.warning("managed cloud compute plan:")
            for compute in self.configs:
                logger.warning(f"    ----------------------------")
                logger.warning(f"    actions: {', '.join(compute.actions)}")
                logger.warning(f"    num replicas: {compute.num_replicas}")
                logger.warning(f"    cpu kind: {compute.cpu_kind}")
                logger.warning(f"    cpus: {compute.cpus}")
                logger.warning(f"    memory mb: {compute.memory_mb}")
                logger.warning(f"    regions: {compute.regions}")

            logger.warning(
                "NOTICE: local mode detected, skipping cloud registration and running all actions locally."
            )

    def get_compute_configs(
        self, actions: Dict[str, Callable[..., Any]]
    ) -> List[ManagedWorkerCreateRequestRuntimeConfig]:
        """
        Builds a map of compute hashes to compute configs and lists of actions that correspond to each compute hash.
        """
        map: Dict[str, ManagedWorkerCreateRequestRuntimeConfig] = {}

        try:
            for action, func in actions.items():
                compute = func._step_compute

                if compute is None:
                    continue

                key = compute.hash()
                if key not in map:
                    map[key] = ManagedWorkerCreateRequestRuntimeConfig(
                        actions=[],
                        num_replicas=1,
                        cpu_kind=compute.cpu_kind,
                        cpus=compute.cpus,
                        memory_mb=compute.memory_mb,
                        regions=compute.regions,
                        slots=self.max_runs,
                    )
                map[key].actions.append(action)

            return list(map.values())
        except Exception as e:
            logger.error(f"Error getting compute configs: {e}")
            return []

    async def cloud_register(self):

        # if the environment variable HATCHET_CLOUD_REGISTER_ID is set, use it and exit
        if self.cloud_register_enabled is not None:
            logger.info(
                f"Registering cloud compute plan with ID: {self.cloud_register_enabled}"
            )

            try:
                if len(self.configs) == 0:
                    logger.warning(
                        "No actions to register, skipping cloud registration."
                    )
                    return

                req = InfraAsCodeCreateRequest(runtime_configs=self.configs)

                res = (
                    await self.client.rest.aio.managed_worker_api.infra_as_code_create(
                        infra_as_code_request=self.cloud_register_enabled,
                        infra_as_code_create_request=req,
                        _request_timeout=10,
                    )
                )

                sys.exit(0)
            except Exception as e:
                print("ERROR", e)
                sys.exit(1)



# coding: utf-8

"""
    Hatchet API

    The Hatchet API

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from typing import Any, Dict, List, Optional, Tuple, Union

from pydantic import Field, StrictFloat, StrictInt, StrictStr, validate_call
from typing_extensions import Annotated

from hatchet_sdk.clients.cloud_rest.api_client import ApiClient, RequestSerialized
from hatchet_sdk.clients.cloud_rest.api_response import ApiResponse
from hatchet_sdk.clients.cloud_rest.models.infra_as_code_create_request import (
    InfraAsCodeCreateRequest,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_create_request import (
    ManagedWorkerCreateRequest,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_events_list200_response import (
    ManagedWorkerEventsList200Response,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_instances_list200_response import (
    ManagedWorkerInstancesList200Response,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_list200_response import (
    ManagedWorkerList200Response,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_list200_response_rows_inner import (
    ManagedWorkerList200ResponseRowsInner,
)
from hatchet_sdk.clients.cloud_rest.models.managed_worker_update_request import (
    ManagedWorkerUpdateRequest,
)
from hatchet_sdk.clients.cloud_rest.models.runtime_config_list_actions200_response import (
    RuntimeConfigListActions200Response,
)
from hatchet_sdk.clients.cloud_rest.rest import RESTResponseType


class ManagedWorkerApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    async def infra_as_code_create(
        self,
        infra_as_code_request: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The infra as code request id",
            ),
        ],
        infra_as_code_create_request: Optional[InfraAsCodeCreateRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Create Infra as Code

        Registers runtime configs via infra-as-code

        :param infra_as_code_request: The infra as code request id (required)
        :type infra_as_code_request: str
        :param infra_as_code_create_request:
        :type infra_as_code_create_request: InfraAsCodeCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._infra_as_code_create_serialize(
            infra_as_code_request=infra_as_code_request,
            infra_as_code_create_request=infra_as_code_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": None,
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def infra_as_code_create_with_http_info(
        self,
        infra_as_code_request: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The infra as code request id",
            ),
        ],
        infra_as_code_create_request: Optional[InfraAsCodeCreateRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Create Infra as Code

        Registers runtime configs via infra-as-code

        :param infra_as_code_request: The infra as code request id (required)
        :type infra_as_code_request: str
        :param infra_as_code_create_request:
        :type infra_as_code_create_request: InfraAsCodeCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._infra_as_code_create_serialize(
            infra_as_code_request=infra_as_code_request,
            infra_as_code_create_request=infra_as_code_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": None,
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def infra_as_code_create_without_preload_content(
        self,
        infra_as_code_request: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The infra as code request id",
            ),
        ],
        infra_as_code_create_request: Optional[InfraAsCodeCreateRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Infra as Code

        Registers runtime configs via infra-as-code

        :param infra_as_code_request: The infra as code request id (required)
        :type infra_as_code_request: str
        :param infra_as_code_create_request:
        :type infra_as_code_create_request: InfraAsCodeCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._infra_as_code_create_serialize(
            infra_as_code_request=infra_as_code_request,
            infra_as_code_create_request=infra_as_code_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": None,
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _infra_as_code_create_serialize(
        self,
        infra_as_code_request,
        infra_as_code_create_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if infra_as_code_request is not None:
            _path_params["infra-as-code-request"] = infra_as_code_request
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if infra_as_code_create_request is not None:
            _body_params = infra_as_code_create_request

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["cookieAuth", "bearerAuth"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/api/v1/cloud/infra-as-code/{infra-as-code-request}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def managed_worker_create(
        self,
        tenant: Annotated[
            str,
            Field(
                min_length=36, strict=True, max_length=36, description="The tenant id"
            ),
        ],
        managed_worker_create_request: Optional[ManagedWorkerCreateRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ManagedWorkerList200ResponseRowsInner:
        """Create Managed Worker

        Create a managed worker for the tenant

        :param tenant: The tenant id (required)
        :type tenant: str
        :param managed_worker_create_request:
        :type managed_worker_create_request: ManagedWorkerCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_create_serialize(
            tenant=tenant,
            managed_worker_create_request=managed_worker_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def managed_worker_create_with_http_info(
        self,
        tenant: Annotated[
            str,
            Field(
                min_length=36, strict=True, max_length=36, description="The tenant id"
            ),
        ],
        managed_worker_create_request: Optional[ManagedWorkerCreateRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ManagedWorkerList200ResponseRowsInner]:
        """Create Managed Worker

        Create a managed worker for the tenant

        :param tenant: The tenant id (required)
        :type tenant: str
        :param managed_worker_create_request:
        :type managed_worker_create_request: ManagedWorkerCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_create_serialize(
            tenant=tenant,
            managed_worker_create_request=managed_worker_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def managed_worker_create_without_preload_content(
        self,
        tenant: Annotated[
            str,
            Field(
                min_length=36, strict=True, max_length=36, description="The tenant id"
            ),
        ],
        managed_worker_create_request: Optional[ManagedWorkerCreateRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Managed Worker

        Create a managed worker for the tenant

        :param tenant: The tenant id (required)
        :type tenant: str
        :param managed_worker_create_request:
        :type managed_worker_create_request: ManagedWorkerCreateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_create_serialize(
            tenant=tenant,
            managed_worker_create_request=managed_worker_create_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _managed_worker_create_serialize(
        self,
        tenant,
        managed_worker_create_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if tenant is not None:
            _path_params["tenant"] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if managed_worker_create_request is not None:
            _body_params = managed_worker_create_request

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["cookieAuth", "bearerAuth"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/api/v1/cloud/tenants/{tenant}/managed-worker",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def managed_worker_delete(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ManagedWorkerList200ResponseRowsInner:
        """Delete Managed Worker

        Delete a managed worker for the tenant

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_delete_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
            "404": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def managed_worker_delete_with_http_info(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ManagedWorkerList200ResponseRowsInner]:
        """Delete Managed Worker

        Delete a managed worker for the tenant

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_delete_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
            "404": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def managed_worker_delete_without_preload_content(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Managed Worker

        Delete a managed worker for the tenant

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_delete_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
            "404": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _managed_worker_delete_serialize(
        self,
        managed_worker,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if managed_worker is not None:
            _path_params["managed-worker"] = managed_worker
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # authentication setting
        _auth_settings: List[str] = ["cookieAuth", "bearerAuth"]

        return self.api_client.param_serialize(
            method="DELETE",
            resource_path="/api/v1/cloud/managed-worker/{managed-worker}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def managed_worker_events_list(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ManagedWorkerEventsList200Response:
        """Get Managed Worker Events

        Get events for a managed worker

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_events_list_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerEventsList200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def managed_worker_events_list_with_http_info(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ManagedWorkerEventsList200Response]:
        """Get Managed Worker Events

        Get events for a managed worker

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_events_list_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerEventsList200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def managed_worker_events_list_without_preload_content(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Managed Worker Events

        Get events for a managed worker

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_events_list_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerEventsList200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _managed_worker_events_list_serialize(
        self,
        managed_worker,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if managed_worker is not None:
            _path_params["managed-worker"] = managed_worker
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # authentication setting
        _auth_settings: List[str] = ["cookieAuth", "bearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v1/cloud/managed-worker/{managed-worker}/events",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def managed_worker_get(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ManagedWorkerList200ResponseRowsInner:
        """Get Managed Worker

        Get a managed worker for the tenant

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_get_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
            "404": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def managed_worker_get_with_http_info(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ManagedWorkerList200ResponseRowsInner]:
        """Get Managed Worker

        Get a managed worker for the tenant

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_get_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
            "404": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def managed_worker_get_without_preload_content(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Managed Worker

        Get a managed worker for the tenant

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_get_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
            "404": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _managed_worker_get_serialize(
        self,
        managed_worker,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if managed_worker is not None:
            _path_params["managed-worker"] = managed_worker
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # authentication setting
        _auth_settings: List[str] = ["cookieAuth", "bearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v1/cloud/managed-worker/{managed-worker}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def managed_worker_instances_list(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ManagedWorkerInstancesList200Response:
        """List Instances

        Get all instances for a managed worker

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_instances_list_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerInstancesList200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def managed_worker_instances_list_with_http_info(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ManagedWorkerInstancesList200Response]:
        """List Instances

        Get all instances for a managed worker

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_instances_list_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerInstancesList200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def managed_worker_instances_list_without_preload_content(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Instances

        Get all instances for a managed worker

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_instances_list_serialize(
            managed_worker=managed_worker,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerInstancesList200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _managed_worker_instances_list_serialize(
        self,
        managed_worker,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if managed_worker is not None:
            _path_params["managed-worker"] = managed_worker
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # authentication setting
        _auth_settings: List[str] = ["cookieAuth", "bearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v1/cloud/managed-worker/{managed-worker}/instances",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def managed_worker_list(
        self,
        tenant: Annotated[
            str,
            Field(
                min_length=36, strict=True, max_length=36, description="The tenant id"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ManagedWorkerList200Response:
        """List Managed Workers

        Get all managed workers for the tenant

        :param tenant: The tenant id (required)
        :type tenant: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_list_serialize(
            tenant=tenant,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def managed_worker_list_with_http_info(
        self,
        tenant: Annotated[
            str,
            Field(
                min_length=36, strict=True, max_length=36, description="The tenant id"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ManagedWorkerList200Response]:
        """List Managed Workers

        Get all managed workers for the tenant

        :param tenant: The tenant id (required)
        :type tenant: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_list_serialize(
            tenant=tenant,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def managed_worker_list_without_preload_content(
        self,
        tenant: Annotated[
            str,
            Field(
                min_length=36, strict=True, max_length=36, description="The tenant id"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Managed Workers

        Get all managed workers for the tenant

        :param tenant: The tenant id (required)
        :type tenant: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_list_serialize(
            tenant=tenant,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _managed_worker_list_serialize(
        self,
        tenant,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if tenant is not None:
            _path_params["tenant"] = tenant
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # authentication setting
        _auth_settings: List[str] = ["cookieAuth", "bearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v1/cloud/tenants/{tenant}/managed-worker",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def managed_worker_update(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        managed_worker_update_request: Optional[ManagedWorkerUpdateRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ManagedWorkerList200ResponseRowsInner:
        """Update Managed Worker

        Update a managed worker for the tenant

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param managed_worker_update_request:
        :type managed_worker_update_request: ManagedWorkerUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_update_serialize(
            managed_worker=managed_worker,
            managed_worker_update_request=managed_worker_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
            "404": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def managed_worker_update_with_http_info(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        managed_worker_update_request: Optional[ManagedWorkerUpdateRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ManagedWorkerList200ResponseRowsInner]:
        """Update Managed Worker

        Update a managed worker for the tenant

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param managed_worker_update_request:
        :type managed_worker_update_request: ManagedWorkerUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_update_serialize(
            managed_worker=managed_worker,
            managed_worker_update_request=managed_worker_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
            "404": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def managed_worker_update_without_preload_content(
        self,
        managed_worker: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The managed worker id",
            ),
        ],
        managed_worker_update_request: Optional[ManagedWorkerUpdateRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Managed Worker

        Update a managed worker for the tenant

        :param managed_worker: The managed worker id (required)
        :type managed_worker: str
        :param managed_worker_update_request:
        :type managed_worker_update_request: ManagedWorkerUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._managed_worker_update_serialize(
            managed_worker=managed_worker,
            managed_worker_update_request=managed_worker_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "ManagedWorkerList200ResponseRowsInner",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
            "404": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _managed_worker_update_serialize(
        self,
        managed_worker,
        managed_worker_update_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if managed_worker is not None:
            _path_params["managed-worker"] = managed_worker
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if managed_worker_update_request is not None:
            _body_params = managed_worker_update_request

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ["application/json"]
            )
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["cookieAuth", "bearerAuth"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/api/v1/cloud/managed-worker/{managed-worker}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def runtime_config_list_actions(
        self,
        runtime_config: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The runtime config id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RuntimeConfigListActions200Response:
        """Get Runtime Config Actions

        Get a list of runtime config actions for a managed worker

        :param runtime_config: The runtime config id (required)
        :type runtime_config: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._runtime_config_list_actions_serialize(
            runtime_config=runtime_config,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "RuntimeConfigListActions200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def runtime_config_list_actions_with_http_info(
        self,
        runtime_config: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The runtime config id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[RuntimeConfigListActions200Response]:
        """Get Runtime Config Actions

        Get a list of runtime config actions for a managed worker

        :param runtime_config: The runtime config id (required)
        :type runtime_config: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._runtime_config_list_actions_serialize(
            runtime_config=runtime_config,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "RuntimeConfigListActions200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def runtime_config_list_actions_without_preload_content(
        self,
        runtime_config: Annotated[
            str,
            Field(
                min_length=36,
                strict=True,
                max_length=36,
                description="The runtime config id",
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Runtime Config Actions

        Get a list of runtime config actions for a managed worker

        :param runtime_config: The runtime config id (required)
        :type runtime_config: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._runtime_config_list_actions_serialize(
            runtime_config=runtime_config,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "RuntimeConfigListActions200Response",
            "400": "MetadataGet400Response",
            "403": "MetadataGet400Response",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _runtime_config_list_actions_serialize(
        self,
        runtime_config,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if runtime_config is not None:
            _path_params["runtime-config"] = runtime_config
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # authentication setting
        _auth_settings: List[str] = ["cookieAuth", "bearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v1/cloud/runtime-config/{runtime-config}/actions",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )
